@@ -28,8 +28,8 @@ config.runtime.nonstandardSymbol  =
 "支持非标准的符号。请务必确认你的运行环境支持这些符号。"
 config.runtime.plugin             =
 "插件路径，请查阅[文档](https://luals.github.io/wiki/plugins)了解用法。"
-config.runtime.pluginArgs         = -- TODO: need translate!
-"Additional arguments for the plugin."
+config.runtime.pluginArgs         =
+"插件的额外参数。"
 config.runtime.fileEncoding       =
 "文件编码，`ansi` 选项只在 `Windows` 平台下有效。"
 config.runtime.builtin            =
@@ -48,8 +48,8 @@ config.diagnostics.disable        =
 "禁用的诊断（使用浮框括号内的代码）。"
 config.diagnostics.globals        =
 "已定义的全局变量。"
-config.diagnostics.globalsRegex   = -- TODO: need translate!
-"Find defined global variables using regex."
+config.diagnostics.globalsRegex   =
+"启用诊断以检测尝试关闭非对象的变量。"
 config.diagnostics.severity       =
 [[
 修改诊断等级。
@@ -280,6 +280,10 @@ config.misc.parameters                   =
 'VSCode中启动语言服务时的[命令行参数](https://luals.github.io/wiki/usage#arguments)。'
 config.misc.executablePath               =
 'VSCode中指定可执行文件路径。'
+config.language.fixIndent                =
+'(仅VSCode) 修复错误的自动缩进，例如在包含单词 "function" 的字符串中换行时出现的错误缩进。'
+config.language.completeAnnotation       =
+'(仅VSCode) 在注解后换行时自动插入 "---@ "。'
 config.type.castNumberToInteger          =
 '允许将 `number` 类型赋给 `integer` 类型。'
 config.type.weakUnionCheck               =
@@ -354,12 +358,12 @@ config.diagnostics['cast-type-mismatch']    =
 '变量被转换为与其初始类型不匹配的类型'
 config.diagnostics['circular-doc-class']    =
 '两个类相互继承并互相循环'
-config.diagnostics['close-non-object']      = -- TODO: need translate!
-'Enable diagnostics for attempts to close a variable with a non-object.'
+config.diagnostics['close-non-object']      =
+'尝试关闭非对象变量的诊断'
 config.diagnostics['code-after-break']      =
 '放在循环中break语句后面的代码'
-config.diagnostics['codestyle-check']       = -- TODO: need translate!
-'Enable diagnostics for incorrectly styled lines.'
+config.diagnostics['codestyle-check']       =
+'启用对不正确样式行的诊断'
 config.diagnostics['count-down-loop']       =
 'for循环永远无法达到最大/极限值(在递减时递增)'
 config.diagnostics['deprecated']            =
@@ -406,9 +410,9 @@ config.diagnostics['redundant-return-value']=
 '返回`@return`注释未指定的额外值'
 config.diagnostics['return-type-mismatch']  =
 '返回值的类型与`@return`中声明的类型不匹配'
-config.diagnostics['spell-check']           = -- TODO: need translate!
-'Enable diagnostics for typos in strings.'
-config.diagnostics['name-style-check']      = -- TODO: need translate!
+config.diagnostics['spell-check']           =
+'启用字符串拼写检查的诊断。'
+config.diagnostics['name-style-check']      =
 '变量的名称样式检查'
 config.diagnostics['unbalanced-assignments']=
 '多重赋值时没有赋值所有变量(如`local x,y = 1`)'
@@ -428,8 +432,8 @@ config.diagnostics['unknown-operator']      =
 '未知的运算符'
 config.diagnostics['unreachable-code']      =
 '不可达的代码'
-config.diagnostics['global-element']       = -- TODO: need translate!
-'Enable diagnostics to warn about global elements.'
+config.diagnostics['global-element']       =
+'启用诊断以警告全局元素。'
 config.typeFormat.config                    =
 '配置输入Lua代码时的格式化行为'
 config.typeFormat.config.auto_complete_end  =
